@@ -20,13 +20,11 @@ object handlers, and its subclass :class:`DXDataObject` is the abstract
 base class for all remote data object handlers.
 """
 
-import time, re, requests, sys, json
+import time, re, sys, json, copy
+
 from dxpy import *
 import dxpy.api
 from dxpy.exceptions import *
-import copy
-
-NUM_HTTP_THREADS = 4
 
 
 class DXObject(object):
@@ -491,14 +489,16 @@ class DXDataObject(DXObject):
             time.sleep(2)
             elapsed += 2
 
+from dxdataobject_functions import *
+
 from dxfile import *
 from dxfile_functions import *
 from dxgtable import *
 from dxgtable_functions import *
 from dxrecord import *
+from dxworkflow import *
 from dxproject import *
 from dxjob import *
 from dxapplet import *
 from dxapp import *
 from search import *
-from dxdataobject_functions import *
