@@ -22,11 +22,10 @@ contents of describe hashes for various DNAnexus entities (projects,
 containers, dataobjects, apps, and jobs).
 '''
 
-import datetime, time, json, math, sys
+import datetime, time, json, math, sys, copy
 from collections import defaultdict
-from copy import copy
 
-from dxpy.utils.printing import *
+from dxpy.utils.printing import (RED, GREEN, BLUE, YELLOW, WHITE, BOLD, ENDC, DELIMITER, get_delimiter, fill)
 
 def JOB_STATES(state):
     if state == 'failed':
@@ -257,7 +256,7 @@ def render_bundleddepends(thing):
 def render_execdepends(thing):
     rendered = []
     for item in thing:
-        dep = copy(item)
+        dep = copy.copy(item)
         dep.setdefault('package_manager', 'apt')
         dep['version'] = ' = '+dep['version'] if 'version' in dep else ''
         rendered.append("{package_manager}: {name}{version}".format(**dep))
@@ -575,7 +574,7 @@ def print_job_desc(desc):
             same_folder = cloned_hash["folder"] == desc["folder"] or not same_project
             print_field(" output folder", ("" if same_project else YELLOW()) + \
                             cloned_hash["project"] + \
-                            ("" if same_project else END()) + ":" + \
+                            ("" if same_project else ENDC()) + ":" + \
                             ("" if same_folder else YELLOW()) + \
                             cloned_hash["folder"] + \
                             (" (same)" if (same_project and same_folder) else "" if same_folder else ENDC()))
